package org.dive4elements.river.importer.parsers;

import java.math.BigDecimal;

import java.text.ParseException;

import org.apache.log4j.Logger;

import org.dive4elements.river.importer.ImportBedHeight;
import org.dive4elements.river.importer.ImportBedHeightEpoch;
import org.dive4elements.river.importer.ImportBedHeightEpochValue;


/** Parses BedHeightEpochs from csv file. */
public class BedHeightEpochParser extends BedHeightParser {

    /** Our own logger. */
    private static final Logger log =
        Logger.getLogger(BedHeightEpochParser.class);


    @Override
    protected ImportBedHeight newImportBedHeight(String description) {
        return new ImportBedHeightEpoch(description);
    }


    /**
     * Handle a non-comment, none-Metadata line of csv file, adding
     * ImportBedHeightEpochValues to the given ImportBedHeight object.
     */
    @Override
    protected void handleDataLine(ImportBedHeight obj, String line) {
        String[] values = line.split(SEPERATOR_CHAR);

        if (values == null || values.length == 0 || values[0].length() == 0) {
            // There might be quite some ";" found.
            //log.warn("Skip invalid data line: " + line);
            return;
        }

        BigDecimal km;

        try {
            km = new BigDecimal(nf.parse(values[0]).doubleValue());
        }
        catch (ParseException e) {
            log.warn("Unparseable number in data row: " + line);
            return;
        }


        // Handle "gap" lines like '255,0;'
        if (values.length < 2) {
            ImportBedHeightEpochValue value = new ImportBedHeightEpochValue(
                km,
                null
            );

            obj.addValue(value);
            return;
        }

        try {
            ImportBedHeightEpochValue value = new ImportBedHeightEpochValue(
                km,
                new BigDecimal(nf.parse(values[1]).doubleValue())
            );

            obj.addValue(value);
        }
        catch (ParseException e) {
            log.warn("Unparseable number in data row: " + line);
        }
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
